# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have old versions of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Class-Load-XS
Version:	0.09
Release:	6.%{__distinit}%{__distvers}
Summary:	XS implementation of parts of Class::Load
Group:		Development/Libraries
License:	Artistic 2.0
URL:		http://search.cpan.org/dist/Class-Load-XS/
Source0:	http://search.cpan.org/CPAN/authors/id/E/ET/ETHER/Class-Load-XS-%{version}.tar.gz
Patch2:		Class-Load-XS-0.07-tm088.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
# ===================================================================
# Module build requirements
# ===================================================================
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 6 || 0%{?rhel} > 5
BuildRequires:	perl-devel
%endif
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# ===================================================================
# Module requirements
# ===================================================================
BuildRequires:	perl(Class::Load) >= 0.20
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# ===================================================================
# Regular test suite requirements
# ===================================================================
BuildRequires:	perl(constant)
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(lib)
BuildRequires:	perl(Module::Implementation) >= 0.04
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Requires)
BuildRequires:	perl(Test::Without::Module)
BuildRequires:	perl(version)
# ===================================================================
# Runtime requirements
# ===================================================================
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%{?perl_default_filter}

%description
This module provides an XS implementation for portions of Class::Load.
See Class::Load for API details.

%prep
%setup -q -n Class-Load-XS-%{version}

# We need to patch the test suite if we have an old version of Test::More
%if %{old_test_more}
%patch2
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes CONTRIBUTING README
%{perl_vendorarch}/auto/Class/
%{perl_vendorarch}/Class/
%{_mandir}/man3/Class::Load::XS.3*

%changelog
* Tue Aug  9 2016 Paul Howarth <paul@city-fan.org> - 0.09-6
- BR: perl-devel and perl-generators where available
- Simplify find commands using -empty and -delete

* Thu Nov 13 2014 Paul Howarth <paul@city-fan.org> - 0.09-1
- Updated to 0.09
  - Optimized some perl API calls

* Mon Sep 15 2014 Paul Howarth <paul@city-fan.org> - 0.08-4
- Drop support for building with ExtUtils::MakeMaker < 6.30
- Drop support for building without Test::Requires
- Use Test::Without::Module unconditionally
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Thu Feb 13 2014 Paul Howarth <paul@city-fan.org> - 0.08-1
- Update to 0.08:
  - Switched packaging to just EUMM, as MBT wants the .xs file in a different
    place
- Switch to ExtUtils::MakeMaker flow

* Thu Feb 13 2014 Paul Howarth <paul@city-fan.org> - 0.07-1
- Update to 0.07:
  - Repository moved to the github moose organization
- This release by ETHER -> update source URL
- Switch to Module::Build::Tiny flow
- Package upstream's CONTRIBUTING and README.md files
- Update patches as needed
- Don't bother with the author/release tests

* Wed Jul 24 2013 Paul Howarth <paul@city-fan.org> - 0.06-3
- Perl 5.18 rebuild

* Mon Oct  8 2012 Paul Howarth <paul@city-fan.org> - 0.06-1
- Update to 0.06:
  - Require Class::Load 0.20 in the code, not just the distro metadata
    (CPAN RT#80002)
  - Weird classes with either an ISA or VERSION constant would cause the XS to
    blow up badly (CPAN RT#79998)
  - Fixed some broken logic that lead to a segfault from the
    014-weird-constants.t test on some Perls (CPAN RT#80059)
- Bump perl(Class::Load) version requirement to 0.20
- Drop explicit requirement for perl(Class::Load), no longer needed
- Update patch for building with Test::More < 0.88

* Thu Jul 12 2012 Paul Howarth <paul@city-fan.org> - 0.04-2
- BR: perl(lib) and perl(XSLoader)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Don't need to run the test suite with LC_ALL=C
  - Use %%{_fixperms} macro rather than PERL_INSTALL_ROOT

* Thu Feb  9 2012 Paul Howarth <paul@city-fan.org> - 0.04-1
- Update to 0.04:
  - Some small test changes for the latest Module::Implementation and
    Class::Load
- Bump Class::Load version requirement to 0.15
- BR: perl(constant), perl(Module::Implementation) ≥ 0.04,
  perl(Test::Requires), perl(Test::Without::Module) and perl(version) for test
  suite
- Add patch to work around absence of Test::Requires if necessary
- Update patch for building with Test::More < 0.88

* Fri Nov 18 2011 Paul Howarth <paul@city-fan.org> - 0.03-1
- Update to 0.03:
  - Explicitly include Test::Fatal as a test prerequisite (CPAN RT#72493)
- Update patch for building with Test::More < 0.88

* Wed Nov 16 2011 Paul Howarth <paul@city-fan.org> - 0.02-1
- Initial RPM version
